Method: Flexkey::CharPool#available_char_pools

Defined in:
lib/flexkey/char_pool.rb

#available_char_poolsHash{ Symbol => String }

Provides a list of the available built-in character pool types with the characters of each type.

Examples:

Flexkey::CharPool.available_char_pools

Returns:

  • (Hash{ Symbol => String })

    a hash of character pool types and their characters



56
57
58
# File 'lib/flexkey/char_pool.rb', line 56

def available_char_pools
  character_types.inject({}) { |acc, (k, v)| acc[k] = v.join; acc }
end