Method: Flexkey::Generator#char_pool

Defined in:
lib/flexkey/generator.rb

#char_poolHash{ String => Symbol, String }

Returns a pool of available character types specified in the format.

Returns:

  • (Hash{ String => Symbol, String })

    a pool of available character types specified in the format



10
11
12
# File 'lib/flexkey/generator.rb', line 10

def char_pool
  @char_pool
end